.. async-py-bus documentation master file, created by
sphinx-quickstart on Tue Jan 28 13:11:18 2025.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive.

async-py-bus documentation
==========================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.


.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :hidden:

   readthedocs/modules

   readthedocs/pybus
   readthedocs/pybus.core
   readthedocs/pybus.core.api
   readthedocs/pybus.core.inspection
   readthedocs/pybus.core.dependency

   readthedocs/pybus.base
   readthedocs/pybus.base.engine
   readthedocs/pybus.base.handlers
   readthedocs/pybus.base.routers

